Module debug

Module debug 

This module contains all the tools that the watch() function needs.

Structs

DebugInfo
A struct containing postmortem debug information that will be sent with something that implements the SubmitMethod trait, through watch().

Traits

SubmitMethod
The trait that needs to be implemented for using the watch() function.