watch

Function watch 

pub fn watch<F>(method: F)
where F: SubmitMethod + 'static,
This function is used to send debug information, using the submit() function from the method parameter when the Rust application panics.