This module contains all the tools that the watch() function needs.
Structs
- Debug
Info - A struct containing postmortem debug information that will be sent with
something that implements the
SubmitMethodtrait, throughwatch().
Traits
- Submit
Method - The trait that needs to be implemented for using the
watch()function.